#################################################
# Distribution Dymanics for GDP per worker EU27 #
#################################################

rm(list=ls(all=TRUE))
#graphics.off()

library(foreach)
library(doMC)
library(base)
registerDoMC(1)

#Load dataset
#load("datasetNUTS2_CE2010_EU27_forGRV_analysis")
load("AlldataDrivers_CE2016.RData")

#Explanation of the dataset
# -GDP per worker of 269 regions for the years 1991-2014 is "GDPpw.1991.2014.final"
# -GDP per worker in RELATIVE terms "GDPpwRel.1991.2014.final"


numYears <- ncol(GDPpwRel.1991.2014.final)

#Firtst and last year of the sample
PROD.InitialYear.REL <- (GDPpwRel.1991.2014.final[,1])  
PROD.FinalYear.REL <-  (GDPpwRel.1991.2014.final[,(numYears)])

    #=========================================================#
    # Density distributions for GDP PER WORKER relative terms #
    #=========================================================#
     
    #Estimate and plot the histogram 
    estimateDensityFinalYear_hist <- hist(PROD.FinalYear.REL) 
     
    #----------------------------------------------------------#
    # Estimate and plot the kernel density using "sm" function #
    library(sm)
    #----------------------------------------------------------#
    estimateDensityFinalYear_sm <- sm.density(PROD.FinalYear.REL)
	
	#To add normality test
	sm.density(PROD.FinalYear.REL, model="normal")


	#Estimate and plot the kernel density using "univariate" function
	#------------------------------------------------------#	
	# Estimation of univariate density via Adaptive Kernel #
	source("univariateDensityAdaptive_Parallel.r")
	#--------------------------------------------------------------#
	# Calculation of the weighted standard deviation of a variable #
	source("weighted.sd.r")

    estimateDensityFinalYear_univ <- univariateDensityAdaptive_Parallel(PROD.FinalYear.REL, figure=TRUE)

	#Bootstrap for confidence bands	
    sm.density(PROD.FinalYear.REL)
        B <-100
    for (b in 1:B){
    	PROD.FinalYear.REL_boot <- sample(PROD.FinalYear.REL, replace=TRUE)
    	sm.density(PROD.FinalYear.REL_boot, add=TRUE)
    }

    estimateDensityFinalYear_sm <- sm.density(PROD.FinalYear.REL, col="red", add=T)
    
    
    #=============================================================================================#
    # Reproducing figure of estimated densities in "2018_slides_Economics_European_Regions_V.pdf" #
    #=============================================================================================#
    
    yRel1991 <- GDPpwRel.1991.2014.final[,colnames(GDPpwRel.1991.2014.final)=="1991"]
    yRel2006 <- GDPpwRel.1991.2014.final[,colnames(GDPpwRel.1991.2014.final)=="2006"]
    yRel2014 <- GDPpwRel.1991.2014.final[,colnames(GDPpwRel.1991.2014.final)=="2014"]
    
    yRel1991Dens <- univariateDensityAdaptive_Parallel(yRel1991, figure=FALSE)
    yRel2006Dens <- univariateDensityAdaptive_Parallel(yRel2006, figure=FALSE)
    yRel2014Dens <- univariateDensityAdaptive_Parallel(yRel2014, figure=FALSE)
    
    dev.new()
    plot(yRel1991Dens$eval.points, yRel1991Dens$estimate,type="l",xlab="Relative per worker GDP", ylab="Density", xlim=c(0,2.25) , ylim=c(0,1.6), lwd=2, lty="dashed")      
    lines(yRel2006Dens$eval.points, yRel2006Dens$estimate,lwd=2,col="black", lty="dotted")         
    lines(yRel2014Dens$eval.points, yRel2014Dens$estimate,lwd=2.5,col="black", lty=1)
    legend("topright",c("1991", "2006", "2014"),col = c("black","black","black"),text.col= "black",lwd=c(2,2,2,2), lty=c(3,2,1,4), merge = TRUE, y.intersp = 1, x.intersp = 0.5,bg="lightgray")
    
    grid(nx=10,ny=10)
    
    #To save the plot in eps format
    dev.copy2eps(file="distrOBS_GDPpw1991_2014.eps",height=8,width=8)
    
